window.Gleam.initSearch([{"doc":"franz","title":"franz","content":"# franz\n\n[![Package Version](https://img.shields.io/hexpm/v/franz)](https://hex.pm/packages/franz)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/franz/)\n\n`franz` is a Gleam library for interacting with Kafka. It provides functionalities to produce and consume messages, handle topics, and manage configurations.\n\n## Installation\n\nAdd `franz` to your Gleam project:\n\n```sh\ngleam add franz\n```\n\n## Usage\n\n```gleam\n  import franz\n  import franz/consumer_config\n  import franz/group_config\n  import franz/group_subscriber\n  import franz/message_type\n  import franz/partitions\n  import franz/producer\n  import franz/topic_subscriber\n  import gleam/io\n\n  pub fn main() {\n    let topic = &quot;gleamy_topic&quot;\n    let endpoint = #(&quot;localhost&quot;, 9092)\n    let assert Ok(connection) =\n      franz.new_client([endpoint])\n      |&gt; franz.with_config(franz.AutoStartProducers(True))\n      |&gt; franz.start()\n\n    //let assert Ok(Nil) = franz.create_topic([endpoint], topic, 1, 1)\n\n    let assert Ok(Nil) =\n      producer.produce_sync(\n        connection,\n        topic,\n        producer.Partitioner(producer.Random),\n        &lt;&lt;&quot;gracias&quot;&gt;&gt;,\n        producer.Value(&lt;&lt;&quot;bitte&quot;&gt;&gt;, [#(&quot;meta&quot;, &quot;data&quot;)]),\n      )\n\n    let counter = 0\n    let assert Ok(_pid) =\n      group_subscriber.new(\n        connection,\n        &quot;group&quot;,\n        [topic],\n        message_type.Message,\n        fn(message, counter) {\n          io.debug(message)\n          io.debug(counter)\n          group_subscriber.commit(counter + 1)\n        },\n        counter,\n      )\n      |&gt; group_subscriber.with_group_config(\n        group_config.OffsetCommitIntervalSeconds(10),\n      )\n      |&gt; group_subscriber.with_consumer_config(consumer_config.BeginOffset(\n        consumer_config.Earliest,\n      ))\n      |&gt; group_subscriber.start()\n\n    let assert Ok(_pid) =\n      topic_subscriber.new(\n        connection,\n        topic,\n        partitions.All,\n        message_type.Message,\n        fn(_, message, state) {\n          io.debug(message)\n          topic_subscriber.ack(state)\n        },\n        Nil,\n      )\n      |&gt; topic_subscriber.with_config(consumer_config.BeginOffset(\n        consumer_config.Earliest,\n      ))\n      |&gt; topic_subscriber.start()\n  }\n```\n","url":"index.html"},{"doc":"franz/producer_config","title":"Compression","content":"pub type Compression {\n  NoCompression\n  Gzip\n  Snappy\n}\n\nNoCompression\n\n\nGzip\n\n\nSnappy\n\n\nSynonyms:\nfranz/producer_config.Compression\nfranz/producer_config Compression","url":"franz/producer_config.html#Compression"},{"doc":"franz/producer_config","title":"ProducerConfig","content":"pub type ProducerConfig {\n  RequiredAcks(Int)\n  AckTimeout(Int)\n  PartitionBufferLimit(Int)\n  PartitionOnwireLimit(Int)\n  MaxBatchSize(Int)\n  MaxRetries(Int)\n  RetryBackoffMs(Int)\n  Compression(Compression)\n  MaxLingerMs(Int)\n  MaxLingerCount(Int)\n}\n\nRequiredAcks(Int)\n\n\nAckTimeout(Int)\n\n\nPartitionBufferLimit(Int)\n\n\nPartitionOnwireLimit(Int)\n\n\nMaxBatchSize(Int)\n\n\nMaxRetries(Int)\n\n\nRetryBackoffMs(Int)\n\n\nCompression(Compression)\n\n\nMaxLingerMs(Int)\n\n\nMaxLingerCount(Int)\n\n\nSynonyms:\nfranz/producer_config.ProducerConfig\nfranz/producer_config ProducerConfig","url":"franz/producer_config.html#ProducerConfig"},{"doc":"franz/producer_config","title":"franz/producer_config","content":"","url":"franz/producer_config.html"},{"doc":"franz","title":"ClientBuilder","content":"pub opaque type ClientBuilder\n\n\nSynonyms:\nfranz.ClientBuilder\nfranz ClientBuilder","url":"franz.html#ClientBuilder"},{"doc":"franz","title":"ClientConfig","content":"pub type ClientConfig {\n  RestartDelaySeconds(Int)\n  GetMetadataTimeoutSeconds(Int)\n  ReconnectCoolDownSeconds(Int)\n  AllowTopicAutoCreation(Bool)\n  AutoStartProducers(Bool)\n  DefaultProducerConfig(List(producer_config.ProducerConfig))\n  UnknownTopicCacheTtl(Int)\n}\n\nRestartDelaySeconds(Int)\n\n\nGetMetadataTimeoutSeconds(Int)\n\n\nReconnectCoolDownSeconds(Int)\n\n\nAllowTopicAutoCreation(Bool)\n\n\nAutoStartProducers(Bool)\n\n\nDefaultProducerConfig(List(producer_config.ProducerConfig))\n\n\nUnknownTopicCacheTtl(Int)\n\n\nSynonyms:\nfranz.ClientConfig\nfranz ClientConfig","url":"franz.html#ClientConfig"},{"doc":"franz","title":"FranzClient","content":"pub type FranzClient\n\n\nSynonyms:\nfranz.FranzClient\nfranz FranzClient","url":"franz.html#FranzClient"},{"doc":"franz","title":"FranzError","content":"pub type FranzError {\n  UnknownError\n  ClientDown\n  UnknownTopicOrPartition\n  ProducerDown\n  TopicAlreadyExists\n  ConsumerNotFound(String)\n  ProducerNotFound(String, Int)\n}\n\nUnknownError\n\n\nClientDown\n\n\nUnknownTopicOrPartition\n\n\nProducerDown\n\n\nTopicAlreadyExists\n\n\nConsumerNotFound(String)\n\n\nProducerNotFound(String, Int)\n\n\nSynonyms:\nfranz.FranzError\nfranz FranzError","url":"franz.html#FranzError"},{"doc":"franz","title":"KafkaMessage","content":"pub type KafkaMessage {\n  KafkaMessage(\n    offset: Int,\n    key: BitArray,\n    value: BitArray,\n    timestamp_type: TimeStampType,\n    timestamp: Int,\n    headers: List(#(String, String)),\n  )\n  KafkaMessageSet(\n    topic: Topic,\n    partition: Int,\n    high_wm_offset: Int,\n    messages: List(KafkaMessage),\n  )\n}\n\nKafkaMessage(\n  offset: Int,\n  key: BitArray,\n  value: BitArray,\n  timestamp_type: TimeStampType,\n  timestamp: Int,\n  headers: List(#(String, String)),\n)\n\n\nKafkaMessageSet(\n  topic: Topic,\n  partition: Int,\n  high_wm_offset: Int,\n  messages: List(KafkaMessage),\n)\n\n\nSynonyms:\nfranz.KafkaMessage\nfranz KafkaMessage","url":"franz.html#KafkaMessage"},{"doc":"franz","title":"Offset","content":"pub type Offset =\n  Int\n\n\nSynonyms:\nfranz.Offset\nfranz Offset","url":"franz.html#Offset"},{"doc":"franz","title":"Partition","content":"pub type Partition =\n  Int\n\n\nSynonyms:\nfranz.Partition\nfranz Partition","url":"franz.html#Partition"},{"doc":"franz","title":"TimeStampType","content":"pub type TimeStampType {\n  Undefined\n  Create\n  Append\n}\n\nUndefined\n\n\nCreate\n\n\nAppend\n\n\nSynonyms:\nfranz.TimeStampType\nfranz TimeStampType","url":"franz.html#TimeStampType"},{"doc":"franz","title":"Topic","content":"pub type Topic =\n  String\n\n\nSynonyms:\nfranz.Topic\nfranz Topic","url":"franz.html#Topic"},{"doc":"franz","title":"create_topic","content":"pub fn create_topic(\n  bootstrap_endpoints: List(#(String, Int)),\n  topic: String,\n  partitions: Int,\n  replication_factor: Int,\n) -&gt; Result(Nil, FranzError)\n\nSynonyms:\nfranz.create_topic\nfranz create_topic","url":"franz.html#create_topic"},{"doc":"franz","title":"fetch","content":"pub fn fetch(\n  client: FranzClient,\n  topic: String,\n  partition: Int,\n  offset: Int,\n) -&gt; Result(#(Int, KafkaMessage), FranzError)\n\nSynonyms:\nfranz.fetch\nfranz fetch","url":"franz.html#fetch"},{"doc":"franz","title":"new_client","content":"pub fn new_client(\n  bootstrap_endpoints: List(#(String, Int)),\n) -&gt; ClientBuilder\n\nSynonyms:\nfranz.new_client\nfranz new_client","url":"franz.html#new_client"},{"doc":"franz","title":"start","content":"pub fn start(\n  client_builder: ClientBuilder,\n) -&gt; Result(FranzClient, FranzError)\n\nSynonyms:\nfranz.start\nfranz start","url":"franz.html#start"},{"doc":"franz","title":"stop_client","content":"pub fn stop_client(client: FranzClient) -&gt; Nil\n\nSynonyms:\nfranz.stop_client\nfranz stop_client","url":"franz.html#stop_client"},{"doc":"franz","title":"with_config","content":"pub fn with_config(\n  client_builder: ClientBuilder,\n  client_config: ClientConfig,\n) -&gt; ClientBuilder\n\nSynonyms:\nfranz.with_config\nfranz with_config","url":"franz.html#with_config"},{"doc":"franz","title":"franz","content":"","url":"franz.html"},{"doc":"franz/consumer_config","title":"ConsumerConfig","content":"pub type ConsumerConfig {\n  BeginOffset(OffsetTime)\n  MinBytes(Int)\n  MaxBytes(Int)\n  MaxWaitTime(Int)\n  SleepTimeout(Int)\n  PrefetchCount(Int)\n  PrefetchBytes(Int)\n  OffsetResetPolicy(OffsetResetPolicy)\n  SizeStatWindow(Int)\n  IsolationLevel(IsolationLevel)\n  ShareLeaderConn(Bool)\n}\n\nBeginOffset(OffsetTime)\n\n\nMinBytes(Int)\n\n\nMaxBytes(Int)\n\n\nMaxWaitTime(Int)\n\n\nSleepTimeout(Int)\n\n\nPrefetchCount(Int)\n\n\nPrefetchBytes(Int)\n\n\nOffsetResetPolicy(OffsetResetPolicy)\n\n\nSizeStatWindow(Int)\n\n\nIsolationLevel(IsolationLevel)\n\n\nShareLeaderConn(Bool)\n\n\nSynonyms:\nfranz/consumer_config.ConsumerConfig\nfranz/consumer_config ConsumerConfig","url":"franz/consumer_config.html#ConsumerConfig"},{"doc":"franz/consumer_config","title":"IsolationLevel","content":"pub type IsolationLevel {\n  ReadCommitted\n  ReadUncommitted\n}\n\nReadCommitted\n\n\nReadUncommitted\n\n\nSynonyms:\nfranz/consumer_config.IsolationLevel\nfranz/consumer_config IsolationLevel","url":"franz/consumer_config.html#IsolationLevel"},{"doc":"franz/consumer_config","title":"OffsetResetPolicy","content":"pub type OffsetResetPolicy {\n  ResetBySubscriber\n  ResetToEarliest\n  ResetToLatest\n}\n\nResetBySubscriber\n\n\nResetToEarliest\n\n\nResetToLatest\n\n\nSynonyms:\nfranz/consumer_config.OffsetResetPolicy\nfranz/consumer_config OffsetResetPolicy","url":"franz/consumer_config.html#OffsetResetPolicy"},{"doc":"franz/consumer_config","title":"OffsetTime","content":"pub type OffsetTime {\n  Earliest\n  Latest\n  MessageTimestamp(Int)\n}\n\nEarliest\n\n\nLatest\n\n\nMessageTimestamp(Int)\n\n\nSynonyms:\nfranz/consumer_config.OffsetTime\nfranz/consumer_config OffsetTime","url":"franz/consumer_config.html#OffsetTime"},{"doc":"franz/consumer_config","title":"franz/consumer_config","content":"","url":"franz/consumer_config.html"},{"doc":"franz/group_config","title":"GroupConfig","content":"pub type GroupConfig {\n  SessionTimeoutSeconds(Int)\n  RebalanceTimeoutSeconds(Int)\n  HeartbeatRateSeconds(Int)\n  MaxRejoinAttempts(Int)\n  RejoinDelaySeconds(Int)\n  OffsetCommitIntervalSeconds(Int)\n  OffsetRetentionSeconds(Int)\n}\n\nSessionTimeoutSeconds(Int)\n\n\nRebalanceTimeoutSeconds(Int)\n\n\nHeartbeatRateSeconds(Int)\n\n\nMaxRejoinAttempts(Int)\n\n\nRejoinDelaySeconds(Int)\n\n\nOffsetCommitIntervalSeconds(Int)\n\n\nOffsetRetentionSeconds(Int)\n\n\nSynonyms:\nfranz/group_config.GroupConfig\nfranz/group_config GroupConfig","url":"franz/group_config.html#GroupConfig"},{"doc":"franz/group_config","title":"franz/group_config","content":"","url":"franz/group_config.html"},{"doc":"franz/message_type","title":"MessageType","content":"pub type MessageType {\n  Message\n  MessageSet\n}\n\nMessage\n\n\nMessageSet\n\n\nSynonyms:\nfranz/message_type.MessageType\nfranz/message_type MessageType","url":"franz/message_type.html#MessageType"},{"doc":"franz/message_type","title":"franz/message_type","content":"","url":"franz/message_type.html"},{"doc":"franz/group_subscriber","title":"CallbackReturn","content":"pub type CallbackReturn\n\n\nSynonyms:\nfranz/group_subscriber.CallbackReturn\nfranz/group_subscriber CallbackReturn","url":"franz/group_subscriber.html#CallbackReturn"},{"doc":"franz/group_subscriber","title":"GroupBuilder","content":"pub type GroupBuilder(callback_init_state) {\n  GroupBuilder(\n    client: franz.FranzClient,\n    group_id: String,\n    topics: List(String),\n    message_type: message_type.MessageType,\n    callback: fn(franz.KafkaMessage, callback_init_state) -&gt;\n      CallbackReturn,\n    init_callback_state: callback_init_state,\n    group_config: List(group_config.GroupConfig),\n    consumer_config: List(consumer_config.ConsumerConfig),\n  )\n}\n\nGroupBuilder(\n  client: franz.FranzClient,\n  group_id: String,\n  topics: List(String),\n  message_type: message_type.MessageType,\n  callback: fn(franz.KafkaMessage, callback_init_state) -&gt;\n    CallbackReturn,\n  init_callback_state: callback_init_state,\n  group_config: List(group_config.GroupConfig),\n  consumer_config: List(consumer_config.ConsumerConfig),\n)\n\n\nSynonyms:\nfranz/group_subscriber.GroupBuilder\nfranz/group_subscriber GroupBuilder","url":"franz/group_subscriber.html#GroupBuilder"},{"doc":"franz/group_subscriber","title":"ack","content":"pub fn ack(cb_state: a) -&gt; CallbackReturn\n\nSynonyms:\nfranz/group_subscriber.ack\nfranz/group_subscriber ack","url":"franz/group_subscriber.html#ack"},{"doc":"franz/group_subscriber","title":"commit","content":"pub fn commit(cb_state: a) -&gt; CallbackReturn\n\nSynonyms:\nfranz/group_subscriber.commit\nfranz/group_subscriber commit","url":"franz/group_subscriber.html#commit"},{"doc":"franz/group_subscriber","title":"new","content":"pub fn new(\n  client: FranzClient,\n  group_id: String,\n  topics: List(String),\n  message_type: MessageType,\n  callback: fn(KafkaMessage, a) -&gt; CallbackReturn,\n  init_callback_state: a,\n) -&gt; GroupBuilder(a)\n\nSynonyms:\nfranz/group_subscriber.new\nfranz/group_subscriber new","url":"franz/group_subscriber.html#new"},{"doc":"franz/group_subscriber","title":"start","content":"pub fn start(\n  group_builder: GroupBuilder(a),\n) -&gt; Result(Pid, FranzError)\n\nSynonyms:\nfranz/group_subscriber.start\nfranz/group_subscriber start","url":"franz/group_subscriber.html#start"},{"doc":"franz/group_subscriber","title":"with_consumer_config","content":"pub fn with_consumer_config(\n  group_builder: GroupBuilder(a),\n  consumer_config: ConsumerConfig,\n) -&gt; GroupBuilder(a)\n\nSynonyms:\nfranz/group_subscriber.with_consumer_config\nfranz/group_subscriber with_consumer_config","url":"franz/group_subscriber.html#with_consumer_config"},{"doc":"franz/group_subscriber","title":"with_group_config","content":"pub fn with_group_config(\n  group_builder: GroupBuilder(a),\n  group_config: GroupConfig,\n) -&gt; GroupBuilder(a)\n\nSynonyms:\nfranz/group_subscriber.with_group_config\nfranz/group_subscriber with_group_config","url":"franz/group_subscriber.html#with_group_config"},{"doc":"franz/group_subscriber","title":"franz/group_subscriber","content":"","url":"franz/group_subscriber.html"},{"doc":"franz/partitions","title":"Partitions","content":"pub type Partitions {\n  Partititons(List(Int))\n  All\n}\n\nPartititons(List(Int))\n\n\nAll\n\n\nSynonyms:\nfranz/partitions.Partitions\nfranz/partitions Partitions","url":"franz/partitions.html#Partitions"},{"doc":"franz/partitions","title":"franz/partitions","content":"","url":"franz/partitions.html"},{"doc":"franz/producer","title":"Partitioner","content":"pub type Partitioner {\n  PartitionFun(\n    fn(String, Int, BitArray, BitArray) -&gt; Result(Int, Nil),\n  )\n  Random\n  Hash\n}\n\nPartitionFun(\n  fn(String, Int, BitArray, BitArray) -&gt; Result(Int, Nil),\n)\n\n\nRandom\n\n\nHash\n\n\nSynonyms:\nfranz/producer.Partitioner\nfranz/producer Partitioner","url":"franz/producer.html#Partitioner"},{"doc":"franz/producer","title":"ProducerBuilder","content":"pub opaque type ProducerBuilder\n\n\nSynonyms:\nfranz/producer.ProducerBuilder\nfranz/producer ProducerBuilder","url":"franz/producer.html#ProducerBuilder"},{"doc":"franz/producer","title":"ProducerPartition","content":"pub type ProducerPartition {\n  Partition(Int)\n  Partitioner(Partitioner)\n}\n\nPartition(Int)\n\n\nPartitioner(Partitioner)\n\n\nSynonyms:\nfranz/producer.ProducerPartition\nfranz/producer ProducerPartition","url":"franz/producer.html#ProducerPartition"},{"doc":"franz/producer","title":"Value","content":"pub type Value {\n  Value(value: BitArray, headers: List(#(String, String)))\n  ValueWithTimestamp(\n    value: BitArray,\n    timestamp: Int,\n    headers: List(#(String, String)),\n  )\n}\n\nValue(value: BitArray, headers: List(#(String, String)))\n\n\nValueWithTimestamp(\n  value: BitArray,\n  timestamp: Int,\n  headers: List(#(String, String)),\n)\n\n\nSynonyms:\nfranz/producer.Value\nfranz/producer Value","url":"franz/producer.html#Value"},{"doc":"franz/producer","title":"new","content":"pub fn new(client: FranzClient, topic: String) -&gt; ProducerBuilder\n\nSynonyms:\nfranz/producer.new\nfranz/producer new","url":"franz/producer.html#new"},{"doc":"franz/producer","title":"produce","content":"pub fn produce(\n  client: FranzClient,\n  topic: String,\n  partition: ProducerPartition,\n  key: BitArray,\n  value: Value,\n) -&gt; Result(Nil, FranzError)\n\nSynonyms:\nfranz/producer.produce\nfranz/producer produce","url":"franz/producer.html#produce"},{"doc":"franz/producer","title":"produce_cb","content":"pub fn produce_cb(\n  client: FranzClient,\n  topic: String,\n  partition: ProducerPartition,\n  key: BitArray,\n  value: Value,\n  callback: fn(Int, Int) -&gt; a,\n) -&gt; Result(Int, FranzError)\n\nSynonyms:\nfranz/producer.produce_cb\nfranz/producer produce_cb","url":"franz/producer.html#produce_cb"},{"doc":"franz/producer","title":"produce_sync","content":"pub fn produce_sync(\n  client: FranzClient,\n  topic: String,\n  partition: ProducerPartition,\n  key: BitArray,\n  value: Value,\n) -&gt; Result(Nil, FranzError)\n\nSynonyms:\nfranz/producer.produce_sync\nfranz/producer produce_sync","url":"franz/producer.html#produce_sync"},{"doc":"franz/producer","title":"produce_sync_offset","content":"pub fn produce_sync_offset(\n  client: FranzClient,\n  topic: String,\n  partition: ProducerPartition,\n  key: BitArray,\n  value: Value,\n) -&gt; Result(Int, FranzError)\n\nSynonyms:\nfranz/producer.produce_sync_offset\nfranz/producer produce_sync_offset","url":"franz/producer.html#produce_sync_offset"},{"doc":"franz/producer","title":"start","content":"pub fn start(builder: ProducerBuilder) -&gt; Result(Nil, FranzError)\n\nSynonyms:\nfranz/producer.start\nfranz/producer start","url":"franz/producer.html#start"},{"doc":"franz/producer","title":"with_config","content":"pub fn with_config(\n  builder: ProducerBuilder,\n  config: ProducerConfig,\n) -&gt; ProducerBuilder\n\nSynonyms:\nfranz/producer.with_config\nfranz/producer with_config","url":"franz/producer.html#with_config"},{"doc":"franz/producer","title":"franz/producer","content":"","url":"franz/producer.html"},{"doc":"franz/topic_subscriber","title":"Ack","content":"pub type Ack\n\n\nSynonyms:\nfranz/topic_subscriber.Ack\nfranz/topic_subscriber Ack","url":"franz/topic_subscriber.html#Ack"},{"doc":"franz/topic_subscriber","title":"Builder","content":"pub opaque type Builder(callback_init_state)\n\n\nSynonyms:\nfranz/topic_subscriber.Builder\nfranz/topic_subscriber Builder","url":"franz/topic_subscriber.html#Builder"},{"doc":"franz/topic_subscriber","title":"ack","content":"pub fn ack(cb_state: a) -&gt; Ack\n\nSynonyms:\nfranz/topic_subscriber.ack\nfranz/topic_subscriber ack","url":"franz/topic_subscriber.html#ack"},{"doc":"franz/topic_subscriber","title":"new","content":"pub fn new(\n  client: FranzClient,\n  topic: String,\n  partitions: Partitions,\n  message_type: MessageType,\n  callback: fn(Int, KafkaMessage, a) -&gt; Ack,\n  init_callback_state: a,\n) -&gt; Builder(a)\n\nSynonyms:\nfranz/topic_subscriber.new\nfranz/topic_subscriber new","url":"franz/topic_subscriber.html#new"},{"doc":"franz/topic_subscriber","title":"start","content":"pub fn start(builder: Builder(a)) -&gt; Result(Pid, FranzError)\n\nSynonyms:\nfranz/topic_subscriber.start\nfranz/topic_subscriber start","url":"franz/topic_subscriber.html#start"},{"doc":"franz/topic_subscriber","title":"with_commited_offset","content":"pub fn with_commited_offset(\n  builder: Builder(a),\n  partition: Int,\n  offset: Int,\n) -&gt; Builder(a)\n\nSynonyms:\nfranz/topic_subscriber.with_commited_offset\nfranz/topic_subscriber with_commited_offset","url":"franz/topic_subscriber.html#with_commited_offset"},{"doc":"franz/topic_subscriber","title":"with_config","content":"pub fn with_config(\n  builder: Builder(a),\n  consumer_config: ConsumerConfig,\n) -&gt; Builder(a)\n\nSynonyms:\nfranz/topic_subscriber.with_config\nfranz/topic_subscriber with_config","url":"franz/topic_subscriber.html#with_config"},{"doc":"franz/topic_subscriber","title":"franz/topic_subscriber","content":"","url":"franz/topic_subscriber.html"}]);